@@ -1,5 +1,3 @@
-extern crate csv;
-
 use std::collections::HashMap;
 use std::error::Error;
 use std::io;
@@ -9,7 +7,7 @@ use std::process;
 // record type.
 type Record = HashMap<String, String>;
 
-fn run() -> Result<(), Box<Error>> {
+fn run() -> Result<(), Box<dyn Error>> {
     let mut rdr = csv::Reader::from_reader(io::stdin());
     for result in rdr.deserialize() {
         let record: Record = result?;
@@ -19,8 +17,8 @@ fn run() -> Result<(), Box<Error>> {
 }
 
 fn main() {
-if let Err(err) = run() {
-println!("{}", err);
-process::exit(1);
-}
+    if let Err(err) = run() {
+        println!("{}", err);
+        process::exit(1);
+    }
 }
